# git revision (as reported by git describe) is used as version minor for snapshots
# set git 0 for full release, 1 for upstream tarball
%define git	1

Name:		phototonic
Version:	2.1.66
Release:	%mkrel 2
Summary:	An image viewer and organizer
Group:		Graphics/Viewers
License:	GPLv3
Url:		http://oferkv.github.io/phototonic/
%if %{git}
Source0:	%{name}-%{version}.tar.gz
%else
Source0:	http://downloads.sourceforge.net/project/%{name}/%{name}-%{version}.tar.gz
%endif
# Run ./mk-tar-git-rev in SOURCES to create snapshot tarball
Source1:	mk-tar-git-rev

BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(exiv2)

Recommends:	%{_lib}qtsvg5
Recommends:	qtimageformats5

%description
Phototonic is an image viewer and organizer with the following features:
* Light weight with a smooth and clear user interface
* Does not depend on any desktop environment
* Supports several customized thumbnail layouts
* Load thumbnails and browse images recursively
* Dynamic thumbnails loading, enabling fast browsing of very large folders
* Filter thumbnails
* Image navigation and file management
* Slide show
* View random image
* Transformation: rotation, flipping, cropping, image mirroring
* Adjust image colors
* Keep transformations zoom and colors while browsing multiple images
* Extensive automatic and manual zoom options
* Supported image formats: 
BMP, GIF, ICO, JPEG, MNG, PBM, PGM, PNG, PPM, SVG, SVGZ, TGA, TIFF, XBM, XPM
* Supports GIF animations
* Keyboard shortcuts and mouse behavior customization
* Load image files or folders from command line
* Open images with external applications

%prep
%setup -q

%build
%qmake_qt5
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# Install translations
mkdir -p %{buildroot}%{_datadir}/%{name}/translations
cp -r translations/*.qm %{buildroot}%{_datadir}/%{name}/translations

# Tweak upstream desktop file
desktop-file-install \
	--dir=%{buildroot}%{_datadir}/applications \
	--add-category='X-Mageia-CrossDesktop' \
	%{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%doc COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/translations
%{_iconsdir}/hicolor/*x*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}.png


%changelog
* Thu Dec 17 2020 umeabot <umeabot> 2.1.66-2.mga8
+ Revision: 1659380
- Rebuild for new Qt5

* Mon Aug 17 2020 barjac <barjac> 2.1.66-1.mga8
+ Revision: 1614641
- new version 2.1.66

* Fri Jun 19 2020 barjac <barjac> 2.1.65-1.mga8
+ Revision: 1596568
- new snapshot 2.1.65

* Fri Jun 05 2020 barjac <barjac> 2.1.54-1.mga8
+ Revision: 1590611
- new version 2.1.54

* Mon Feb 17 2020 umeabot <umeabot> 2.1.14-2.mga8
+ Revision: 1537670
- Mageia 8 Mass Rebuild

* Tue Nov 05 2019 barjac <barjac> 2.1.14-1.mga8
+ Revision: 1458261
- new version 2.1.14

* Thu May 16 2019 daviddavid <daviddavid> 2.1.10-3.mga7
+ Revision: 1398009
- rebuild for new exiv2 0.27.1

* Mon Apr 01 2019 umeabot <umeabot> 2.1.10-2.mga7
+ Revision: 1383907
- Qt5 Rebuild

* Tue Jan 22 2019 barjac <barjac> 2.1.10-1.mga7
+ Revision: 1359158
- new version 2.1.10
- really fix mk-tar-git-rev to exclude .git

* Sat Jan 12 2019 barjac <barjac> 2.1.8-1.mga7
+ Revision: 1355328
- new version 2.1.8
- fix mk-tar-git-rev script

* Fri Jan 11 2019 daviddavid <daviddavid> 2.1.6-3.mga7
+ Revision: 1354803
- rebuild for new exiv2 0.27

* Sun Sep 23 2018 umeabot <umeabot> 2.1.6-2.mga7
+ Revision: 1300206
- Mageia 7 Mass Rebuild

* Sat May 26 2018 barjac <barjac> 2.1.6-1.mga7
+ Revision: 1232228
- new version 2.1.6

* Thu Mar 29 2018 barjac <barjac> 2.1.4-1.mga7
+ Revision: 1213558
- new version 2.1.4

* Mon Jan 29 2018 barjac <barjac> 1.7.43-1.mga7
+ Revision: 1198056
- new version 1.7.43

* Thu Dec 28 2017 barjac <barjac> 1.7.23-1.mga7
+ Revision: 1186768
- new version 1.7.23

* Tue Jun 20 2017 neoclust <neoclust> 1.7.21-2.mga6
+ Revision: 1108008
- Rebuild against new exiv2

* Sun May 22 2016 barjac <barjac> 1.7.21-1.mga6
+ Revision: 1017483
- new version 1.7.21

* Wed May 18 2016 barjac <barjac> 1.7.20-1.mga6
+ Revision: 1016786
- new version 1.7.20

* Tue Jan 26 2016 barjac <barjac> 1.7.19-1.mga6
+ Revision: 927714
- new version 1.7.19

* Sat Jan 16 2016 barjac <barjac> 1.7.16-1.mga6
+ Revision: 924639
- new minor version 1.7.16

* Fri Dec 11 2015 barjac <barjac> 1.7.13-1.mga6
+ Revision: 909448
- new minor version 1.7.13
- make version easier to parse for version checking

* Wed Nov 25 2015 barjac <barjac> 1.7.6-1.mga6
+ Revision: 906032
- new version 1.7.6

* Tue Sep 29 2015 barjac <barjac> 1.6.26-1.mga6
+ Revision: 885067
- new minor version 1.6.26
- bug fixes and translation updates

* Mon Aug 24 2015 barjac <barjac> 1.6.20-1.mga6
+ Revision: 868947
- new version 1.6.20

* Mon Feb 09 2015 barjac <barjac> 1.5.54-1.mga5
+ Revision: 814225
- new snapshot
- minor change to mk-tar-git-rev script

* Sun Nov 23 2014 barjac <barjac> 1.5.10-1.mga5
+ Revision: 798652
- new version 1.5.10

* Wed Oct 15 2014 umeabot <umeabot> 1.4.3-2.mga5
+ Revision: 739276
- Second Mageia 5 Mass Rebuild

* Sat Oct 04 2014 barjac <barjac> 1.4.3-1.mga5
+ Revision: 736811
- update snapshot and patch version string
- bugfixes and translation updates
- new upstream versioning scheme
- changed snapshot script to accomodate new versioning

* Tue Sep 16 2014 umeabot <umeabot> 1.03-4.f06bc10.mga5
+ Revision: 687089
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Fri Sep 12 2014 barjac <barjac> 1.03-3.f06bc10.mga5
+ Revision: 674819
- inadvertently dropped COPYING - replaced
- improved tarball tool mk-tar-git-rev
- new snapshot

* Fri Sep 12 2014 barjac <barjac> 1.03-2.190ce96.mga5
+ Revision: 674809
- new snapshot with many bug fixes

* Thu Aug 14 2014 barjac <barjac> 1.03-1.mga5
+ Revision: 662388
- import new package phototonic

